"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.znRefreshToken = exports.znNumericValue = exports.znLocation = exports.znOpenDropdown = exports.znPluginData = exports.znFetch = exports.znHttp = exports.stopAutoSizing = exports.autoSize = exports.znSizer = exports.znResize = exports.znFiltersPanel = exports.znMessage = exports.znConfirm = exports.znContext = exports.rpcClient = void 0;
var tslib_1 = require("tslib");
var post_rpc_client_1 = tslib_1.__importDefault(require("@zenginehq/post-rpc-client"));
var content_sizer_1 = tslib_1.__importDefault(require("content-sizer"));
var data_utilities_1 = require("./data-utilities");
var parentOrigin = (document.location.ancestorOrigins && document.location.ancestorOrigins[0]) || getReferrerOrigin() || 'https://platform.zenginehq.com';
function getReferrerOrigin() {
    if (document.referrer) {
        var link = document.createElement('a');
        link.href = document.referrer;
        return link.origin || (link.protocol + '//' + link.hostname);
    }
}
exports.rpcClient = new post_rpc_client_1.default(parentOrigin);
exports.rpcClient.logging(false);
exports.rpcClient.start();
window.addEventListener('beforeunload', function () {
    exports.rpcClient.call({ method: 'reloadFrames' });
});
function znContext(callback) {
    return exports.rpcClient.call({ method: 'context', callback: callback });
}
exports.znContext = znContext;
function znConfirm(message, callback) {
    return exports.rpcClient.call({ method: 'confirm', args: { message: message }, callback: callback });
}
exports.znConfirm = znConfirm;
function znMessage(message, type, duration) {
    if (type === void 0) { type = 'info'; }
    if (duration === void 0) { duration = 4000; }
    return exports.rpcClient.call({
        method: 'message',
        args: { params: { message: message, type: type, duration: duration } }
    });
}
exports.znMessage = znMessage;
function znFiltersPanel(options, callback) {
    return callback
        ? exports.rpcClient.call({ method: 'filtersPanel', args: { options: options }, callback: callback })
        : exports.rpcClient.call({ method: 'filtersPanel', args: { options: options } });
}
exports.znFiltersPanel = znFiltersPanel;
function znResize(dimensions) {
    return exports.rpcClient.call({ method: 'resize', args: { dimensions: dimensions } });
}
exports.znResize = znResize;
function updateHandler(dimensions) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var resized;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, znResize(dimensions)
                        .catch(function (err) { return err instanceof Error ? err : new Error(JSON.stringify(err)); })];
                case 1:
                    resized = _a.sent();
                    if (resized instanceof Error) {
                        return [2, null];
                    }
                    return [2, resized];
            }
        });
    });
}
exports.znSizer = new content_sizer_1.default(updateHandler);
function autoSize() {
    exports.znSizer.autoSize();
}
exports.autoSize = autoSize;
function stopAutoSizing() {
    exports.znSizer.stopAutoSize();
}
exports.stopAutoSizing = stopAutoSizing;
function znHttp(request, callback) {
    return exports.rpcClient.call({
        method: 'znHttp',
        args: {
            options: {
                apiVersion: '1'
            },
            request: request
        },
        callback: callback
    });
}
exports.znHttp = znHttp;
function znFetch(param1, param2) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var fetchOptions, url, _a, signal, givenHeaders, sendingMeta, sendingHeaders, fetchStatus, result, body, headers, receivingMeta, response;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    fetchOptions = typeof param1 === 'string' ? param2 : param1;
                    url = typeof param1 === 'string' ? param1 : param1.url;
                    _a = fetchOptions || {}, signal = _a.signal, givenHeaders = _a.headers, sendingMeta = tslib_1.__rest(_a, ["signal", "headers"]);
                    sendingHeaders = givenHeaders instanceof Headers
                        ? {}
                        : givenHeaders || {};
                    if (givenHeaders instanceof Headers) {
                        givenHeaders.forEach(function (value, key) {
                            if (sendingHeaders[key]) {
                                sendingHeaders[key] = sendingHeaders[key] + ", " + value;
                            }
                            else {
                                sendingHeaders[key] = value;
                            }
                        });
                    }
                    fetchStatus = { complete: false };
                    return [4, Promise.race([
                            exports.rpcClient.call({
                                method: 'znFetch',
                                args: {
                                    options: {
                                        apiVersion: '1'
                                    },
                                    url: url,
                                    fetchOptions: tslib_1.__assign({ headers: sendingHeaders }, sendingMeta)
                                }
                            }),
                            listenForAbortSignalOrCompletion(signal, fetchStatus)
                        ])];
                case 1:
                    result = _b.sent();
                    fetchStatus.complete = true;
                    if (result.fetchSignalAborted) {
                        throw new DOMException("Aborted Request: " + url, 'AbortError');
                    }
                    body = result.body, headers = result.headers, receivingMeta = tslib_1.__rest(result, ["body", "headers"]);
                    response = new Response(body, tslib_1.__assign(tslib_1.__assign({}, receivingMeta), { headers: new Headers(headers) }));
                    return [2, response];
            }
        });
    });
}
exports.znFetch = znFetch;
function sleep(ms) {
    return new Promise(function (resolve) { return setTimeout(resolve, ms); });
}
function listenForAbortSignalOrCompletion(signal, fetchStatus) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!fetchStatus.complete) return [3, 2];
                    return [4, sleep(10)];
                case 1:
                    _a.sent();
                    return [2, { fetchSignalAborted: false }];
                case 2:
                    if (signal === null || signal === void 0 ? void 0 : signal.aborted) {
                        return [2, { fetchSignalAborted: true }];
                    }
                    return [4, sleep(50)];
                case 3:
                    _a.sent();
                    return [2, listenForAbortSignalOrCompletion(signal, fetchStatus)];
            }
        });
    });
}
function znPluginData(options, callback) {
    return exports.rpcClient.call({ method: 'znPluginData', args: options, callback: callback });
}
exports.znPluginData = znPluginData;
function znOpenDropdown(options) {
    var _a = options.top, top = _a === void 0 ? 0 : _a, _b = options.right, right = _b === void 0 ? 0 : _b, _c = options.bottom, bottom = _c === void 0 ? 0 : _c, _d = options.left, left = _d === void 0 ? 0 : _d, _e = options.width, width = _e === void 0 ? 400 : _e, _f = options.height, height = _f === void 0 ? 300 : _f, _g = options.events, events = _g === void 0 ? {} : _g, _h = options.side, side = _h === void 0 ? 'bottom' : _h, context = options.context, src = options.src;
    Object.keys(events).forEach(function (key) {
        exports.rpcClient.subscribe(key, events[key]);
    });
    var promise = exports.rpcClient.call({
        method: 'dropdown',
        args: {
            options: tslib_1.__assign(tslib_1.__assign({}, options), { events: Object.keys(events) })
        }
    });
    promise.then(function () {
        Object.keys(events).forEach(function (key) {
            exports.rpcClient.unsubscribe(key);
        });
    });
    return promise;
}
exports.znOpenDropdown = znOpenDropdown;
exports.znLocation = {
    protocol: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'protocol',
            args: []
        }
    }); },
    host: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'host',
            args: []
        }
    }); },
    port: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'port',
            args: []
        }
    }); },
    pathParams: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'pathParams',
            args: []
        }
    }); },
    pathname: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'pathname',
            args: []
        }
    }); },
    reload: function () { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'reload',
            args: []
        }
    }); },
    hash: function (hash) { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'hash',
            args: hash ? [hash] : []
        }
    }); },
    href: function (href) { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'href',
            args: href ? [href] : []
        }
    }); },
    searchParams: function (query, value) { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'searchParams',
            args: query !== undefined && value !== undefined ? [query, value] : []
        }
    }); },
    navigate: function (path) { return exports.rpcClient.call({
        method: 'location',
        args: {
            method: 'navigate',
            args: [path]
        }
    }); }
};
var znNumberWithCommas = function (amount, decimalCount) {
    try {
        var decimal = '.';
        var thousands = ',';
        decimalCount = Math.abs(decimalCount);
        decimalCount = isNaN(decimalCount) ? 2 : decimalCount;
        var integerPart = parseInt(Math.abs(Number(amount) || 0).toFixed(decimalCount), 10).toString(10);
        var digitsToBeRemoved = (integerPart.length > 3) ? integerPart.length % 3 : 0;
        var firstIntPart = digitsToBeRemoved ? integerPart.substr(0, digitsToBeRemoved) + thousands : '';
        var secondIntPart = integerPart.substr(digitsToBeRemoved).replace(/(\d{3})(?=\d)/g, '$1' + thousands);
        var decimalPart = decimalCount ? (decimal + Math.abs(Number(amount) - Number(integerPart)).toFixed(decimalCount).slice(2)) : '';
        var formattedStr = firstIntPart + secondIntPart + decimalPart;
        return formattedStr;
    }
    catch (e) {
        console.log(e);
        return 'NaN';
    }
};
var znCurrencySymbol = function (code) { var _a, _b; return (_b = (_a = data_utilities_1.currencies[code]) === null || _a === void 0 ? void 0 : _a.symbol) !== null && _b !== void 0 ? _b : ''; };
exports.znNumericValue = function (amount, field) {
    var _a;
    var isNegative = amount < 0 ? '-' : '';
    var value = Math.abs(amount);
    var properties = (_a = field === null || field === void 0 ? void 0 : field.settings) === null || _a === void 0 ? void 0 : _a.properties;
    var decimal = (properties === null || properties === void 0 ? void 0 : properties.decimal) ? properties.decimal : 0;
    var formattedValue = znNumberWithCommas(value.toFixed(decimal), decimal);
    var symbol = (properties === null || properties === void 0 ? void 0 : properties.currency) ? znCurrencySymbol(properties.currency || '') : '';
    var result = isNegative + symbol + formattedValue;
    return result;
};
exports.znRefreshToken = function () { return exports.rpcClient.call({ method: 'refreshToken' }); };
